@@ -369,7 +369,7 @@ address.generated-by {
 cpanfile
 ---
 requires 'Nephia'        => '0';
-requires 'Config::Micro' => '0';
+requires 'Config::Micro' => '0.02';
 
 on test => sub {
     requires 'Test::More', '0.98';
